@@ -24,6 +24,18 @@ DEFAULT_BIN_DIRS = [
 ]
 PY2 = sys.version[0] == "2"
 DEFAULT_PYTHON_APP_NAME = "Python Application"
+CONFIG_FILE_REPLACEMENTS = (
+    ("# distributed_tracing.enabled", "distributed_tracing.enabled"),
+    ("distributed_tracing.enabled = false", "distributed_tracing.enabled = true"),
+    (
+        "# application_logging.forwarding.enabled",
+        "application_logging.forwarding.enabled",
+    ),
+    (
+        "application_logging.forwarding.enabled = false",
+        "application_logging.forwarding.enabled = true",
+    ),
+)
 
 
 class RunMode:
@@ -339,19 +351,15 @@ class Process(object):
                 file.seek(0)
                 file.truncate()
 
-                replace = "distributed_tracing.enabled = false"
-                replace_with = "distributed_tracing.enabled = true"
+                for replace, replace_with in CONFIG_FILE_REPLACEMENTS:
+                    file_text = file_text.replace(replace, replace_with)
 
                 if args.region.upper() == "STAGING":
-                    replace_with += "\n\nhost = staging-collector.newrelic.com"
+                    app_name += "\n\nhost = staging-collector.newrelic.com"
 
-                dt_replaced_text = file_text.replace(replace, replace_with)
+                file_text = file_text.replace(DEFAULT_PYTHON_APP_NAME, app_name)
 
-                final_config = dt_replaced_text.replace(
-                    DEFAULT_PYTHON_APP_NAME, app_name
-                )
-
-                file.write(final_config)
+                file.write(file_text)
 
     def install(self, args):
         install_command = self.rewrite_install_command()
@@ -366,10 +374,13 @@ class Process(object):
 
         try:
             process_command = self.rewrite_process_command()
+            if not process_command:
+                raise ValueError("Failed to rewrite process command.")
 
             # Accept -y flag or prompt user for choice.
             yes = args.yes or yes_no_input(
-                "\nAccept above command and restart process?"
+                "\n%s\nAccept above command and restart process?"
+                % " ".join(process_command)
             )
             if not yes:
                 print("\nContinuing introspection without restarting process...")
@@ -531,13 +542,13 @@ def require_arg_defined(arg, args):
 
 
 def require_pid(args):
+    require_arg_defined("pid", args)
     try:
         pid = int(args.pid)
     except ValueError:
         sys.stderr.write("--pid must be an integer, got %s\n" % str(args.pid))
         sys.exit(1)
 
-    require_arg_defined("pid", args)
     if not Process(pid).exists:
         sys.stderr.write("--process with id %d does not exist\n" % pid)
         sys.exit(1)
